<?php

namespace FiloBlu\Storelocator\Block\Adminhtml\Stores;

use Magento\Ui\Component\MassAction\Filter;

/**
 * Abstract items renderer
 * @SuppressWarnings(PHPMD.CouplingBetweenObjects)
 */
class CheckError extends \Magento\Backend\Block\Template {

    protected $_collectionFactory;
    protected $_helper;
    protected $_filter;
    protected $_storesCollection;
    protected $_countryFactory;

    public function __construct(
    \Magento\Backend\Block\Template\Context $context, \Magento\Ui\Component\MassAction\Filter $filter, \FiloBlu\Storelocator\Model\ResourceModel\Stores\CollectionFactory $collectionFactory, \FiloBlu\Storelocator\Helper\Data $helper, \Magento\Directory\Model\CountryFactory $countryFactory, array $data = []
    ) {

        $this->_filter = $filter;
        $this->_collectionFactory = $collectionFactory;
        $this->_helper = $helper;
        $this->_countryFactory = $countryFactory;
        $this->_storesCollection = $this->_filter->getCollection($this->_collectionFactory->create());

        parent::__construct($context, $data);
    }

    public function checkEmptyCoordinates() {
        if (!$this->_helper->getConfig('filoblu_storelocator_section/check_error/check_error_empty_coordinates')) {
            return "This check is not enabled.";
        }
        
        $return = "";
        foreach ($this->_storesCollection as $item) {
            if (!$item->getLatitude() || !$item->getLongitude()) {
                $return .= $item->getId() . " - " . $item->getTitle() . "</br>";
            }
        }

        return $return;
    }

    public function checkValidCoordinates() {
        if (!$this->_helper->getConfig('filoblu_storelocator_section/check_error/check_error_invalid_coordinates_for_country')) {
            return "This check is not enabled.";
        }
        
        $return = "";
        foreach ($this->_storesCollection as $item) {
            if ($item->getLatitude() && $item->getLongitude() && $item->getCountry() && $this->isValidCountry($item->getCountry())) {
                $key = $this->_helper->getConfig('filoblu_storelocator_section/general/gmaps_api_key');
                $url = $this->_helper->getConfig('filoblu_storelocator_section/geocode/gmaps_geocode_api_url') . "?latlng=" . $item->getLatitude() . "," . $item->getLongitude() . "&sensor=false&key={$key}";

                // get the json response
                $resp_json = file_get_contents($url);

                // decode the json
                $resp = json_decode($resp_json, true);

                if ($resp['status'] == 'OK') {

                    if ($address = $resp['results'][0]["address_components"]) {
                        foreach ($address as $row) {
                            if ($row["types"][0] == "country" && $row["short_name"] != $item->getCountry()) {
                                $return .= $item->getId() . " - " . $item->getTitle() . " - VALID COUNTRY IS " . $row["short_name"] . ", CURRENT IS " . $item->getCountry() . "</br>";
                                break;
                            }
                        }
                    } else {
                        $return .= $item->getId() . " - " . $item->getTitle() . " - ERROR GET JSON - NO RESULTS FOR ADDRESS COMPONENTS</br>";
                    }
                } else {
                    $return .= $item->getId() . " - " . $item->getTitle() . " - ERROR GET JSON - " . $resp['error_message'] . "</br>";
                }
            }
        }

        return $return;
    }

    public function checkValidCountry() {
        if (!$this->_helper->getConfig('filoblu_storelocator_section/check_error/check_error_invalid_country_id')) {
            return "This check is not enabled.";
        }
        
        $return = "";
        foreach ($this->_storesCollection as $item) {
            if ($item->getCountry()) {
                if (!$this->isValidCountry($item->getCountry())) {
                    $return .= $item->getId() . " - " . $item->getTitle() . " - INVALID COUNTRY ID - " . $item->getCountry() . "</br>";
                }
            } else {
                $return .= $item->getId() . " - " . $item->getTitle() . " - EMPTY COUNTRY ID</br>";
            }
        }


        return $return;
    }

    public function isValidCountry($countryId) {
        $countryInfo = $this->_countryFactory->create()->loadByCode($countryId);

        if (!$countryInfo->getName()) {
            return false;
        } else {
            return true;
        }
    }

}
